# Scenario

During this workshop a set of products will be created together with the needed
workflows to administer users and user groups. The products will be just
complex enough to show the basic capabilities of products, product blocks,
fixed inputs, resource types and workflows in the workflow orchestrator.

The following user and user group attributes will be stored:

* **UserGroup**
    * **group_name**: name of the user group
    * **group_id**: ID of the group in an imaginary group management system 
* **User**
    * **affiliation**: the user's affiliation (**internal** or **external**)
    * **username**: name of the user
    * **age**: age of the user
    * **user_id**: ID of the user in an imaginary user management system
    * **group**: group the user belongs to
